## 2.0.0 - 2025-10-17

### ✨ Added

- [#1328](https://github.com/edgarrmondragon/citric/issues/1328) Added `user_id` and `username` parameters to `list_users` method

- [#1329](https://github.com/edgarrmondragon/citric/issues/1329) Added `mandatory`, `new_question_title`, `new_question_text` and `new_question_help` parameters to `import_question` method

- [#1369](https://github.com/edgarrmondragon/citric/issues/1369) Added a `get_summary_stat` method to get a specific survey stat

- [#1546](https://github.com/edgarrmondragon/citric/issues/1546) Official support for Python 3.14 and 3.15

- [#1548](https://github.com/edgarrmondragon/citric/issues/1548) Support updating answers using the REST API

- [#1549](https://github.com/edgarrmondragon/citric/issues/1549) Made the `RESTClient` public

### 🔄 Changed

- [#1372](https://github.com/edgarrmondragon/citric/issues/1372) Fixed typo `ExporAdditionalOptions` -> `ExportAdditionalOptions`

### 🐛 Fixed

- [#1351](https://github.com/edgarrmondragon/citric/issues/1351) Added missing fields and removed bad ones from schema of uploaded files response

- [#1445](https://github.com/edgarrmondragon/citric/issues/1445) Use 6.6.0+ `v1/auth` REST endpoints

### 🛠️ Refactored

- [#1354](https://github.com/edgarrmondragon/citric/issues/1354) Remove LimeSurvey version compatibility helpers and rely and good method documentation

- [#1547](https://github.com/edgarrmondragon/citric/issues/1547) Use `enum.StrEnum` to get enum members with the correct `repr()` value

### 📚 Documentation

- [#1423](https://github.com/edgarrmondragon/citric/issues/1423) Update code sample for custom session attributes to set custom headers

### 🏷️ Typing

- [#1374](https://github.com/edgarrmondragon/citric/issues/1374) Annotate the participant fields in the response from `list_participants`

- [#1375](https://github.com/edgarrmondragon/citric/issues/1375) Remove `TYPE_CHECKING` guards in modules that define types

### 📦 Packaging

- [#1371](https://github.com/edgarrmondragon/citric/issues/1371) Removed license trove classifier and rely on PEP 639 (https://peps.python.org/pep-0639/)

- [#1375](https://github.com/edgarrmondragon/citric/issues/1375) Make `typing-extensions` a runtime dependency

- [#1501](https://github.com/edgarrmondragon/citric/issues/1501) Dropped support for Python 3.8
